==> dart_dev-2.0.4.tar.gz: lib/src/reporter.dart <==
// Copyright 2015 Workiva Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

library dart_dev.src.reporter;

import 'dart:async';
import 'dart:io';

import 'package:ansicolor/ansicolor.dart';

Reporter reporter = new Reporter();

final AnsiPen _blue = new AnsiPen()..cyan();
final AnsiPen _green = new AnsiPen()..green();
final AnsiPen _red = new AnsiPen()..red();
final AnsiPen _yellow = new AnsiPen()..yellow();

class Reporter {
  bool _color;
  bool _quiet;

  Reporter({color: true, quiet: false}) {
    this.color = color;
    this.quiet = quiet;
  }

  bool get color => _color;
  bool get quiet => _quiet;

  set color(bool b) => _color = b ?? true;
  set quiet(bool b) => _quiet = b ?? false;

  String colorBlue(String message) => _colorMessage(_blue, message);

  String colorGreen(String message) => _colorMessage(_green, message);

  String colorRed(String message) => _colorMessage(_red, message);

  String colorYellow(String message) => _colorMessage(_yellow, message);

  void log(String message, {bool shout: false}) {
    _log(stdout, message, shout: shout);
  }

  static String _indent(String lines) {
    return '    ' + lines.replaceAll('\n', '\n    ');
  }

  void logGroup(String title,
      {String output,
      String error,
      Stream<String> outputStream,
      Stream<String> errorStream}) {
    var formattedTitle = colorBlue('\n::: $title');

    if (output != null) {
      log(formattedTitle);
      log(_indent(output));
    } else if (error != null) {
      warning(formattedTitle);
      warning(_indent(error));
    } else {
      log(formattedTitle);

      outputStream?.listen((line) {
        log(_indent(line));
      })?.onError((line) {
        warning(_indent(line));
      });
      errorStream?.listen((line) {
        warning(_indent(line));
      })?.onError((line) {
        this.error(_indent(line));
      });
    }
  }

  void error(String message, {bool shout: false}) {
    _log(stderr, colorRed(message), shout: shout);
  }

  void success(String message, {bool shout: false}) {
    log(colorGreen(message), shout: shout);
  }

  void warning(String message, {bool shout: false}) {
    _log(stderr, colorYellow(message), shout: shout);
  }

  String _colorMessage(AnsiPen pen, String message) =>
      color && message.isNotEmpty ? pen(message) : message;

  void _log(IOSink sink, String message, {bool shout: false}) {
    if (quiet && !shout) return;
    sink.writeln(message);
  }
}

==> dart_dev-2.2.1.tar.gz: lib/src/reporter.dart <==
// Copyright 2015 Workiva Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

library dart_dev.src.reporter;

import 'dart:async';
import 'dart:io';

import 'package:ansicolor/ansicolor.dart';

Reporter reporter = new Reporter();

final AnsiPen _blue = new AnsiPen()..cyan();
final AnsiPen _green = new AnsiPen()..green();
final AnsiPen _red = new AnsiPen()..red();
final AnsiPen _yellow = new AnsiPen()..yellow();

class Reporter {
  bool _color;
  bool _quiet;

  Reporter({color: true, quiet: false}) {
    this.color = color;
    this.quiet = quiet;
  }

  bool get color => _color;
  bool get quiet => _quiet;

  set color(bool b) => _color = b ?? true;
  set quiet(bool b) => _quiet = b ?? false;

  String colorBlue(String message) => _colorMessage(_blue, message);

  String colorGreen(String message) => _colorMessage(_green, message);

  String colorRed(String message) => _colorMessage(_red, message);

  String colorYellow(String message) => _colorMessage(_yellow, message);

  void log(String message, {bool shout: false}) {
    _log(stdout, message, shout: shout);
  }

  static String _indent(String lines) {
    return '    ' + lines.replaceAll('\n', '\n    ');
  }

  void logGroup(String title,
      {String output,
      String error,
      Stream<String> outputStream,
      Stream<String> errorStream}) {
    var formattedTitle = colorBlue('\n::: $title');

    if (output != null) {
      log(formattedTitle);
      log(_indent(output));
    } else if (error != null) {
      warning(formattedTitle);
      warning(_indent(error));
    } else {
      log(formattedTitle);

      outputStream?.listen((line) {
        log(_indent(line));
      })?.onError((line) {
        warning(_indent(line));
      });
      errorStream?.listen((line) {
        warning(_indent(line));
      })?.onError((line) {
        this.error(_indent(line));
      });
    }
  }

  void error(String message, {bool shout: false}) {
    message = message ?? 'An error was encountered running the task.';
    _log(stderr, colorRed(message), shout: shout);
  }

  void success(String message, {bool shout: false}) {
    if (message == null) {
      return;
    }
    log(colorGreen(message), shout: shout);
  }

  void warning(String message, {bool shout: false}) {
    if (message == null) {
      return;
    }
    _log(stderr, colorYellow(message), shout: shout);
  }

  String _colorMessage(AnsiPen pen, String message) =>
      color && message != null && message.isNotEmpty ? pen(message) : message;

  void _log(IOSink sink, String message, {bool shout: false}) {
    if (quiet && !shout) return;
    sink.writeln(message);
  }
}
